==> react-final-form-fields-2.0.10.tgz: package/src/components/TextField.js <==
// @flow

import React, { useState } from 'react'
import { Image, Platform } from 'react-native'
import styled from 'styled-components/native'
// import * as Masked from 'react-native-imask'

import { DARKEST_GRAY, GRAY } from '../styles/theme'
import Container from './Container'

type CommonProps = {
  children: React.Element,
  input: Object,
  meta?: Object,
  id?: string,
}

type TextFieldProps = {
  ...CommonProps,
  label: string,
  beforeElement?: any,
  onKeyUp?: () => void,
}

type Props = {
  label: String,
  children: React.Element | String,
  input: Object,
  meta: Object,
  className: String,
  containers?: Object<React.Element> | String,
}

const Field = styled.TextInput`
  flex: 1;
  height: 44;
  padding-horizontal: 16;
  font-size: 16;
  color: ${DARKEST_GRAY};
  border-width: 1;
  border-style: solid;
  border-radius: 4;
  border-color: ${props => {
    return props.meta && props.meta.active ? 'blue' : 'gray;'
  }};
  ${Platform.web === true && 'outline-style: none;'}
`

const FieldContainer = styled.View`
  flex-direction: row;
  background-color: transparent;
  z-index: 0;
  width: 100%;
`

const EyeContainer = styled.TouchableOpacity`
  width: 20;
  height: 20;
  position: absolute;
  top: 13;
  right: 10;
  z-index: 2;
`

const InputElement = ({
  label,
  input,
  input: { type },
  style,
  placeholder,
  meta,
  containers,
  meta: { error, touched, dirty },
  ...rest
}: Props) => {
  const [isShowingPassword, setShowPassword] = useState(false)
  const fieldId = `TextField_${input.name}`
  let Input

  const finalFormProps = [{ ...input }, { meta }]

  console.log('rest', rest)
  // console.log('arguments', arguments)

  switch (type) {
    case 'date':
      Input = (
        <Field
          {...finalFormProps}
          // placeholder={placeholder}
          containers={containers}
          dataDetectorTypes="calendarEvent"
          keyboardType="number-pad"
        />
      )
      break

    case 'pin':
      Input = <Field containers={containers} {...finalFormProps} keyboardType="number-pad" />
      break

    case 'email':
      Input = (
        <Field containers={containers} {...finalFormProps} placeholder={placeholder} keyboardType="email-address" />
      )
      break

    case 'phone':
      Input = (
        <Field
          {...finalFormProps}
          containers={containers}
          keyboardType="phone-pad"
          id={fieldId}
          mask="+{62} 00 0000 0000"
        />
      )
      break

    case 'password':
    case 'newPassword':
      Input = (
        <FieldContainer>
          <Field
            {...finalFormProps}
            containers={containers}
            textContentType={type}
            type={type}
            id={fieldId}
            placeholder={placeholder}
            secureTextEntry={!isShowingPassword}
          />
          <EyeContainer onPress={() => setShowPassword(!isShowingPassword)}>
            <Image
              style={{ height: 20, width: 20 }}
              source={
                isShowingPassword
                  ? require('../assets/icons/icVisibility.png')
                  : require('../assets/icons/icVisibilityOff.png')
              }
            />
          </EyeContainer>
        </FieldContainer>
      )
      break

    default: {
      Input = (
        <Field
          {...finalFormProps}
          containers={containers}
          textContentType={type || 'text'}
          id={fieldId}
          placeholder={placeholder || ''}
        />
      )
    }
  }

  return Input
}

function TextField(props: TextFieldProps) {
  const {
    input,
    input: { type },
    placeholder = '',
    meta: { active = false },
  } = props
  const fieldId = `TextField_${props.input.name}`

  return (
    <Container {...props}>
      {active && props.beforeElement}
      <InputElement type={type || 'text'} id={fieldId} {...props} />
    </Container>
  )
}

export default TextField

==> react-final-form-fields-2.0.11.tgz: package/src/components/TextField.js <==
// @flow

import React, { useState } from 'react'
import { Image, Platform } from 'react-native'
import styled from 'styled-components/native'
// import * as Masked from 'react-native-imask'

import { DARKEST_GRAY, GRAY } from '../styles/theme'
import Container from './Container'

type CommonProps = {
  children: React.Element,
  input: Object,
  meta?: Object,
  id?: string,
}

type TextFieldProps = {
  ...CommonProps,
  label: string,
  beforeElement?: any,
  onKeyUp?: () => void,
}

type Props = {
  label: String,
  children: React.Element | String,
  input: Object,
  meta: Object,
  className: String,
  containers?: Object<React.Element> | String,
}

const Field = styled.TextInput`
  flex: 1;
  height: 44;
  padding-horizontal: 16;
  font-size: 16;
  color: ${DARKEST_GRAY};
  border-width: 1;
  border-style: solid;
  border-radius: 4;
  border-color: ${props => {
    return props.meta && props.meta.active ? 'blue' : 'gray'
  }};
  ${Platform.web === true && 'outline-style: none;'}
`

const FieldContainer = styled.View`
  flex-direction: row;
  background-color: transparent;
  z-index: 0;
  width: 100%;
`

const EyeContainer = styled.TouchableOpacity`
  width: 20;
  height: 20;
  position: absolute;
  top: 13;
  right: 10;
  z-index: 2;
`

const InputElement = ({
  label,
  input,
  input: { type },
  style,
  placeholder,
  meta,
  containers,
  meta: { error, touched, dirty },
  ...rest
}: Props) => {
  const [isShowingPassword, setShowPassword] = useState(false)
  const fieldId = `TextField_${input.name}`
  let Input

  const finalFormProps = [{ ...input }, { meta }]

  console.log('rest', rest)
  // console.log('arguments', arguments)

  switch (type) {
    case 'date':
      Input = (
        <Field
          {...finalFormProps}
          // placeholder={placeholder}
          containers={containers}
          dataDetectorTypes="calendarEvent"
          keyboardType="number-pad"
        />
      )
      break

    case 'pin':
      Input = <Field containers={containers} {...finalFormProps} keyboardType="number-pad" />
      break

    case 'email':
      Input = (
        <Field containers={containers} {...finalFormProps} placeholder={placeholder} keyboardType="email-address" />
      )
      break

    case 'phone':
      Input = (
        <Field
          {...finalFormProps}
          containers={containers}
          keyboardType="phone-pad"
          id={fieldId}
          mask="+{62} 00 0000 0000"
        />
      )
      break

    case 'password':
    case 'newPassword':
      Input = (
        <FieldContainer>
          <Field
            {...finalFormProps}
            containers={containers}
            textContentType={type}
            type={type}
            id={fieldId}
            placeholder={placeholder}
            secureTextEntry={!isShowingPassword}
          />
          <EyeContainer onPress={() => setShowPassword(!isShowingPassword)}>
            <Image
              style={{ height: 20, width: 20 }}
              source={
                isShowingPassword
                  ? require('../assets/icons/icVisibility.png')
                  : require('../assets/icons/icVisibilityOff.png')
              }
            />
          </EyeContainer>
        </FieldContainer>
      )
      break

    default: {
      Input = (
        <Field
          {...finalFormProps}
          containers={containers}
          textContentType={type || 'text'}
          id={fieldId}
          placeholder={placeholder || ''}
        />
      )
    }
  }

  return Input
}

function TextField(props: TextFieldProps) {
  const {
    input,
    input: { type },
    placeholder = '',
    meta: { active = false },
  } = props
  const fieldId = `TextField_${props.input.name}`

  return (
    <Container {...props}>
      {active && props.beforeElement}
      <InputElement type={type || 'text'} id={fieldId} {...props} />
    </Container>
  )
}

export default TextField
